@@ -6,14 +6,13 @@ from ._alg2d_int import integrate_2d  # noqa F401
 from ._alg3d_bpp import backpropagate_3d  # noqa F401
 from ._alg3d_bppt import backpropagate_3d_tilted  # noqa F401
 
-from ._postproc import odt_to_ri, opt_to_ri  # noqa F401
-from ._preproc import sinogram_as_radon, sinogram_as_rytov  # noqa F401
+from ._prepare_sino import sinogram_as_radon, sinogram_as_rytov  # noqa F401
+from ._translate_ri import odt_to_ri, opt_to_ri  # noqa F401
 from ._version import version as __version__  # noqa F401
 from ._version import longversion as __version_full__  # noqa F401
 
+from . import apple  # noqa F401
+
+
 __author__ = "Paul Müller"
 __license__ = "BSD (3 clause)"
-
-
-# Shared variable used by 3D backpropagation
-_shared_array = None
